Zenodo
======

* `Deposition helpers`_
* `File helpers`_

.. automodule:: scarches.zenodo
    :members:
    :undoc-members:
    :show-inheritance:

Deposition helpers
------------------

.. automodule:: scarches.zenodo.deposition
    :members:
    :undoc-members:
    :show-inheritance:

File Helpers
------------

.. automodule:: scarches.zenodo.file
    :members:
    :undoc-members:
    :show-inheritance: